==> 0.0.63.tar.gz: lib/widgets/src/bottom_sheet/date_picker_bottom_sheet.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/widgets/src/card.dart';
import 'package:tengits_widgets/calendar/table_calendar.dart';

import 'common_bottom_sheet.dart';

class DatePickerBottomSheet extends StatefulWidget {
  const DatePickerBottomSheet({Key? key, required this.title, this.initialStartTime}) : super(key: key);

  final String title;
  final DateTime? initialStartTime;

  @override
  State<DatePickerBottomSheet> createState() => _DatePickerBottomSheetState();
}

class _DatePickerBottomSheetState extends State<DatePickerBottomSheet> {
  DateTime? startTime;

  @override
  void initState() {
    super.initState();
    startTime = widget.initialStartTime;
  }

  @override
  Widget build(BuildContext context) {
    return CommonBottomSheet(
      title: widget.title,
      bottomWidgetPadding: const EdgeInsets.all(0),
      contentWidget: Container(
        constraints: BoxConstraints(maxHeight: 270.h),
        child: SingleChildScrollView(
          physics: const AlwaysScrollableScrollPhysics(),
          child: TableCalendar(
            locale: "zh",
            firstDay: DateTime(2000, 1, 1),
            lastDay: DateTime(2050, 12, 31),
            focusedDay: startTime ?? DateTime.now(),
            calendarFormat: CalendarFormat.month,
            selectedDayPredicate: (day) => isSameDay(startTime, day),
            rangeSelectionMode: RangeSelectionMode.toggledOff,
            onDaySelected: (selectedDay, focusedDay) {
              if (!isSameDay(startTime, selectedDay)) {
                setState(() {
                  startTime = selectedDay;
                  Navigator.of(context).pop(selectedDay);
                });
              }
            },
          ),
          // child: BrnCalendarView(
          //   displayMode: DisplayMode.month,
          //   selectMode: SelectMode.single,
          //   initStartSelectedDate: startTime,
          //   dateChange: (value) {
          //     Navigator.of(context).pop(value);
          //   },
          // ),
        ),
      ),
      operatorWidget: const ButtonOperatorCard(buttons: []),
    );
  }
}

==> 0.0.71.tar.gz: lib/widgets/src/bottom_sheet/date_picker_bottom_sheet.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/widgets/src/card.dart';
import 'package:tengits_widgets/calendar/table_calendar.dart';

import 'common_bottom_sheet.dart';

class DatePickerBottomSheet extends StatefulWidget {
  const DatePickerBottomSheet({
    Key? key,
    required this.title,
    this.initialStartTime,
    this.minTime,
    this.maxTime,
  }) : super(key: key);

  final String title;
  final DateTime? initialStartTime;
  final DateTime? minTime;
  final DateTime? maxTime;

  @override
  State<DatePickerBottomSheet> createState() => _DatePickerBottomSheetState();
}

class _DatePickerBottomSheetState extends State<DatePickerBottomSheet> {
  DateTime? startTime;
  DateTime? minTime;
  DateTime? maxTime;

  @override
  void initState() {
    super.initState();
    startTime = widget.initialStartTime;
    if (widget.minTime != null) {
      minTime = widget.minTime!.subtract(const Duration(days: 1));
    }
    maxTime = widget.maxTime;
  }

  @override
  Widget build(BuildContext context) {
    return CommonBottomSheet(
      title: widget.title,
      bottomWidgetPadding: const EdgeInsets.all(0),
      contentWidget: Container(
        constraints: BoxConstraints(minHeight: 270.h),
        padding: EdgeInsets.only(bottom: MediaQuery.of(context).padding.bottom),
        child: SingleChildScrollView(
          physics: const AlwaysScrollableScrollPhysics(),
          child: TableCalendar(
            locale: "zh",
            firstDay: minTime ?? DateTime(DateTime.now().year - 20, 1, 1),
            lastDay: maxTime ?? DateTime(DateTime.now().year + 50, 12, 31),
            focusedDay: startTime ?? DateTime.now(),
            calendarFormat: CalendarFormat.month,
            selectedDayPredicate: (day) => isSameDay(startTime, day),
            rangeSelectionMode: RangeSelectionMode.toggledOff,
            onDaySelected: (selectedDay, focusedDay) {
              if (!isSameDay(startTime, selectedDay)) {
                setState(() {
                  startTime = selectedDay;
                  Navigator.of(context).pop(selectedDay);
                });
              }
            },
          ),
          // child: BrnCalendarView(
          //   displayMode: DisplayMode.month,
          //   selectMode: SelectMode.single,
          //   initStartSelectedDate: startTime,
          //   dateChange: (value) {
          //     Navigator.of(context).pop(value);
          //   },
          // ),
        ),
      ),
      operatorWidget: const ButtonOperatorCard(buttons: []),
    );
  }
}
